@@ -30,7 +30,7 @@ import (
 )
 
 const (
-	version             = "0.5.3"
+	version             = "0.5.4"
 	nsBOSH              = "urn:xmpp:alt-connections:xbosh"
 	nsC2SdTLS           = "urn:xmpp:alt-connections:tls"
 	nsC2SQuic           = "urn:xmpp:alt-connections:quic"
@@ -1088,7 +1088,7 @@ func checkCertExpiry(c *tls.Conn) {
 	case time.Until(expiry).Hours() < 336:
 		fmt.Printf("%s[OK]%s", colorYellow, colorReset)
 		printTLSVersion(c.ConnectionState().Version)
-		fmt.Printf(" (Cert expires in %d days.)\n", int(time.Until(expiry).Hours())%24)
+		fmt.Printf(" (Cert expires in %d days.)\n", int(time.Until(expiry).Hours())/24)
 	case now.Before(expiry) && now.After(start):
 		fmt.Print(statusOK)
 		printTLSVersion(c.ConnectionState().Version)
